@@ -12,12 +12,12 @@ PollStartEvent::PollStartEvent(const QJsonObject &obj)
 
 int PollStartEvent::maxSelections() const
 {
-    return contentJson()["org.matrix.msc3381.poll.start"_ls]["max_selections"_ls].toInt();
+    return contentJson()["org.matrix.msc3381.poll.start"_L1]["max_selections"_L1].toInt();
 }
 
 QString PollStartEvent::question() const
 {
-    return contentJson()["org.matrix.msc3381.poll.start"_ls]["question"_ls]["body"_ls].toString();
+    return contentJson()["org.matrix.msc3381.poll.start"_L1]["question"_L1]["body"_L1].toString();
 }
 
 PollResponseEvent::PollResponseEvent(const QJsonObject &obj)
@@ -32,7 +32,7 @@ PollEndEvent::PollEndEvent(const QJsonObject &obj)
 
 PollResponseEvent::PollResponseEvent(const QString &pollStartEventId, QStringList responses)
     : RoomEvent(basicJson(TypeId,
-                          {{"org.matrix.msc3381.poll.response"_ls, QJsonObject{{"answers"_ls, QJsonArray::fromStringList(responses)}}},
-                           {"m.relates_to"_ls, QJsonObject{{"rel_type"_ls, "m.reference"_ls}, {"event_id"_ls, pollStartEventId}}}}))
+                          {{"org.matrix.msc3381.poll.response"_L1, QJsonObject{{"answers"_L1, QJsonArray::fromStringList(responses)}}},
+                           {"m.relates_to"_L1, QJsonObject{{"rel_type"_L1, "m.reference"_L1}, {"event_id"_L1, pollStartEventId}}}}))
 {
 }
