@@ -3,6 +3,7 @@
 
 #pragma once
 
+#include <Quotient/events/roomevent.h>
 #include <Quotient/room.h>
 
 #include <QCache>
@@ -14,6 +15,8 @@
 
 #include "enums/messagetype.h"
 #include "enums/pushrule.h"
+#include "models/messagecontentmodel.h"
+#include "models/threadmodel.h"
 #include "neochatroommember.h"
 #include "pollhandler.h"
 
@@ -131,22 +134,6 @@ class NeoChatRoom : public Quotient::Room
      */
     Q_PROPERTY(bool readOnly READ readOnly NOTIFY readOnlyChanged)
 
-    /**
-     * @brief The current join rule for the room as a QString.
-     *
-     * Possible values are [public, knock, invite, private, restricted].
-     *
-     * @sa https://spec.matrix.org/v1.5/client-server-api/#mroomjoin_rules
-     */
-    Q_PROPERTY(QString joinRule READ joinRule WRITE setJoinRule NOTIFY joinRuleChanged)
-
-    /**
-     * @brief The space IDs that members of can join this room.
-     *
-     * Empty if the join rule is not restricted.
-     */
-    Q_PROPERTY(QList<QString> restrictedIds READ restrictedIds NOTIFY joinRuleChanged)
-
     /**
      * @brief Get the maximum room version that the server supports.
      *
@@ -211,6 +198,9 @@ class NeoChatRoom : public Quotient::Room
 public:
     explicit NeoChatRoom(Quotient::Connection *connection, QString roomId, Quotient::JoinState joinState = {});
 
+    bool visible() const;
+    void setVisible(bool visible);
+
     [[nodiscard]] QDateTime lastActiveTime();
 
     /**
@@ -414,25 +404,6 @@ public:
 
     bool readOnly() const;
 
-    [[nodiscard]] QString joinRule() const;
-
-    /**
-     * @brief Set the join rule for the room.
-     *
-     * Will fail if the user doesn't have the required privileges.
-     *
-     * @param joinRule the join rule [public, knock, invite, private, restricted].
-     * @param allowedSpaces only used when the join rule is restricted. This is a
-     *        list of space Matrix IDs that members of can join without an invite.
-     *        If the rule is restricted and this list is empty it is treated as a join
-     *        rule of private instead.
-     *
-     * @sa https://spec.matrix.org/latest/client-server-api/#mroomjoin_rules
-     */
-    Q_INVOKABLE void setJoinRule(const QString &joinRule, const QList<QString> &allowedSpaces = {});
-
-    QList<QString> restrictedIds() const;
-
     int maxRoomVersion() const;
 
     /**
@@ -498,14 +469,6 @@ public:
 
     bool canEncryptRoom() const;
 
-    /**
-     * @brief Get the power level for the given user ID in the room.
-     *
-     * Returns the default value for a user in the room if they have no escalated
-     * privileges or if they are not a member so membership should be known before using.
-     */
-    Q_INVOKABLE [[nodiscard]] int getUserPowerLevel(const QString &userId) const;
-
     Q_INVOKABLE void setUserPowerLevel(const QString &userID, const int &powerLevel);
 
     ChatBarCache *mainCache() const;
@@ -570,7 +533,7 @@ public:
      *
      * The result will be nullptr if not found so needs to be managed.
      */
-    const Quotient::RoomEvent *getEvent(const QString &eventId) const;
+    std::pair<const Quotient::RoomEvent *, bool> getEvent(const QString &eventId) const;
 
     /**
      * @brief Returns the event that is being replied to. This includes events that were manually loaded using NeoChatRoom::loadReply.
@@ -590,7 +553,74 @@ public:
      */
     Quotient::FileTransferInfo cachedFileTransferInfo(const Quotient::RoomEvent *event) const;
 
+    /**
+     * @brief Return a NeochatRoomMember object for the given user ID.
+     *
+     * @warning Because we can't guarantee that a member state event is downloaded
+     *          before a message they sent arrives this will create the object unconditionally
+     *          assuming that the state event will turn up later. It is therefor the
+     *          responsibility of the caller to ensure that they only ask for objects
+     *          for real senders.
+     */
+    NeochatRoomMember *qmlSafeMember(const QString &memberId);
+
+    /**
+     * @brief Returns the content model for the given event ID.
+     *
+     * A model is created is one doesn't exist. Will return nullptr if evtOrTxnId
+     * is empty.
+     *
+     * @warning If a non-empty ID is given it is assumed to be a valid Quotient::RoomMessageEvent
+     *          event ID. The caller must ensure that the ID is a real event. A model will be
+     *          returned unconditionally.
+     *
+     * @warning Do NOT use for pending events as this function has no way to differentiate.
+     */
+    MessageContentModel *contentModelForEvent(const QString &evtOrTxnId);
+
+    /**
+     * @brief Returns the content model for the given event.
+     *
+     * A model is created is one doesn't exist. Will return nullptr if event is:
+     *  - nullptr
+     *  - not a Quotient::RoomMessageEvent (e.g a state event)
+     *
+     * @note This method is preferred to the version using just an event ID as it
+     *       can perform some basic checks. If a copy of the event is not available,
+     *       you may have to use the version that takes an event ID.
+     *
+     * @note This version must be used for pending events as it can differentiate.
+     */
+    MessageContentModel *contentModelForEvent(const Quotient::RoomEvent *event);
+
+    /**
+     * @brief Returns the thread model for the given thread root event ID.
+     *
+     * A model is created is one doesn't exist. Will return nullptr if threadRootId
+     * is empty.
+     */
+    Q_INVOKABLE ThreadModel *modelForThread(const QString &threadRootId);
+
+    /**
+     * @brief Pin a message in the room.
+     * @param eventId The id of the event to pin.
+     */
+    Q_INVOKABLE void pinEvent(const QString &eventId);
+
+    /**
+     * @brief Unpin a message in the room.
+     * @param eventId The id of the event to unpin.
+     */
+    Q_INVOKABLE void unpinEvent(const QString &eventId);
+
+    /**
+     * @return True if @p eventId is pinned in the room.
+     */
+    Q_INVOKABLE bool isEventPinned(const QString &eventId) const;
+
 private:
+    bool m_visible = false;
+
     QSet<const Quotient::RoomEvent *> highlights;
 
     bool m_hasFileUploading = false;
@@ -619,6 +649,10 @@ private:
     void cleanupExtraEventRange(Quotient::RoomEventsRange events);
     void cleanupExtraEvent(const QString &eventId);
 
+    std::unordered_map<QString, std::unique_ptr<NeochatRoomMember>> m_memberObjects;
+    std::unordered_map<QString, std::unique_ptr<MessageContentModel>> m_eventContentModels;
+    std::unordered_map<QString, std::unique_ptr<ThreadModel>> m_threadModels;
+
 private Q_SLOTS:
     void updatePushNotificationState(QString type);
 
@@ -641,7 +675,6 @@ Q_SIGNALS:
     void displayNameChanged();
     void pushNotificationStateChanged(PushNotificationState::State state);
     void canEncryptRoomChanged();
-    void joinRuleChanged();
     void historyVisibilityChanged();
     void defaultUrlPreviewStateChanged();
     void urlPreviewEnabledChanged();
@@ -683,40 +716,6 @@ public Q_SLOTS:
      */
     void sendTypingNotification(bool isTyping);
 
-    /**
-     * @brief Send a message to the room.
-     *
-     * @param rawText the text as it was typed.
-     * @param cleanedText the text marked up as html.
-     * @param type the type of message being sent.
-     * @param replyEventId the id of the message being replied to if a reply.
-     * @param relateToEventId the id of the message being edited if an edit.
-     */
-    void postMessage(const QString &rawText,
-                     const QString &cleanedText,
-                     Quotient::MessageEventType type = Quotient::MessageEventType::Text,
-                     const QString &replyEventId = QString(),
-                     const QString &relateToEventId = QString(),
-                     const QString &threadRootId = QString(),
-                     const QString &fallbackId = QString());
-
-    /**
-     * @brief Send an html message to the room.
-     *
-     * @param text the text as it was typed.
-     * @param html the text marked up as html.
-     * @param type the type of message being sent.
-     * @param replyEventId the id of the message being replied to if a reply.
-     * @param relateToEventId the id of the message being edited if an edit.
-     */
-    void postHtmlMessage(const QString &text,
-                         const QString &html,
-                         Quotient::MessageEventType type = Quotient::MessageEventType::Text,
-                         const QString &replyEventId = QString(),
-                         const QString &relateToEventId = QString(),
-                         const QString &threadRootId = QString(),
-                         const QString &fallbackId = QString());
-
     /**
      * @brief Set the room avatar.
      */
